#include <gtk/gtk.h>
#include "window.h"
#include "menu_bar.h"
#include "cell_array_table.h"
#include "button_box.h"
#include "key_table_entry.h"
#include "../config.h"

GtkWidget *main_window;
GtkTooltips *tooltips;

extern gchar *package_pixmaps_dir;
 
/*###################### Add icons to stock item ##################*/

void set_stock_icons() //This function has not been used anywhere in program now.
{
	GtkIconFactory *factory;
	
	static GtkStockItem kmap_stock_icons[]={
		{ "kmap","_Kmap",0,0,NULL},
		{ "developer","_Developer",0,0,NULL},
		{ "bugs","_Bugs",0,0,NULL},
		{ "license","_License",0,0,NULL}
	};
	
	/*array of filename*/
	gchar *kmap_icon_files[]={
		"kmap.png",
		"developer.png",
		"bugs.png",
		"license.png"
	};
	
	/* Register our stock items */ 
	gtk_stock_add(kmap_stock_icons, G_N_ELEMENTS (kmap_stock_icons));
	
	/* Add our custom icon factory to the list of defaults */
	factory = gtk_icon_factory_new ( );
	gtk_icon_factory_add_default (factory);
	
	gint i;
 	/* Register icon to accompany stock item */
	for( i=0 ; i<4 ;i++ )
	{
		GtkIconSet *icon_set;
		GdkPixbuf *pixbuf;
		
		gchar *filename;
		 
		//filename=g_string_new( PACKAGE_PIXMAPS_DIR"/" );
        //g_string_append( filename , gsim_icon_files[ i ] );
#ifdef G_OS_WIN32
		filename=g_build_filename (package_pixmaps_dir, kmap_icon_files[ i ], NULL);
#else
        filename=g_build_filename (PACKAGE_PIXMAPS_DIR, kmap_icon_files[ i ], NULL);
#endif
        		
		pixbuf = gdk_pixbuf_new_from_file( filename, NULL );       
		if( pixbuf )
		{
			icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
			gtk_icon_factory_add (factory, kmap_stock_icons[ i ].stock_id , icon_set);
			gtk_icon_set_unref (icon_set);
			g_object_unref (pixbuf);
			g_free(filename);
		}
		else
        {			
            g_warning("Failed to load stock item %s\n",kmap_icon_files[i] );
            g_free(filename);
        }
	}
	g_object_unref( factory );
	
	return ;
}
	



/*############ Main window's delete event handler##############*/
static gboolean del_event_handler(GtkWidget *window,GdkEvent *event,gpointer data)
{
	return FALSE;
}

/*############### Quit from the application ##################*/
void quit_from_main(GtkWidget *window,gpointer usr_data)
{
	gtk_main_quit();
}


/*#################### Create Main Window #################*/

void create_appwindow(void)
{
	main_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	g_object_set( main_window ,"window-position",GTK_WIN_POS_CENTER,"title","Kmap Disclosure",NULL);
	gtk_window_set_resizable(GTK_WINDOW(main_window),FALSE);
	//set_stock_icons();
	tooltips=gtk_tooltips_new( );
	
	/*################## Create parent table to hold subitems ##################*/
	GtkWidget *parent_table;
	parent_table=gtk_table_new(6,1,FALSE);
	gtk_container_add(GTK_CONTAINER(main_window),parent_table);
	
	/*################# Create and attach menu bar #########################*/
	GtkWidget *menubar;
	menubar=get_menubar();
	gtk_table_attach_defaults(GTK_TABLE(parent_table),menubar,0,1,0,1);
	
	/*################# Create and attach horizontal seperator ###########*/
	GtkWidget *hsep1;
	hsep1=gtk_hseparator_new();
	gtk_table_attach_defaults(GTK_TABLE(parent_table),hsep1,0,1,1,2);
	
	/*################# Create and attach cell array table ###########*/
	GtkWidget *cell_array_table;
	cell_array_table=get_cell_array_table();
	gtk_table_attach(GTK_TABLE(parent_table),cell_array_table,0,1,2,3,0,0,10,10);
	
	GtkWidget *hztl_button_box;
	hztl_button_box=get_button_box();
	gtk_table_attach(GTK_TABLE(parent_table),hztl_button_box,0,1,3,4,0,0,0,1);
	
	GtkWidget *hsep2;
	hsep2=gtk_hseparator_new();
	gtk_table_attach_defaults(GTK_TABLE(parent_table),hsep2,0,1,4,5);
	
	GtkWidget *key_table;
	key_table=get_key_table();
	gtk_table_attach(GTK_TABLE(parent_table),key_table,0,1,5,6,0,0,5,7);
	
		
	gtk_widget_show_all(main_window);
	gtk_widget_hide(key_entry2);
	
    gchar *filename;
				
#ifdef G_OS_WIN32
	filename=g_build_filename (package_pixmaps_dir, "kmap.png", NULL);
#else
    filename=g_build_filename (PACKAGE_PIXMAPS_DIR, "kmap.png", NULL);
#endif

	gtk_window_set_icon_from_file(GTK_WINDOW(main_window),filename,FALSE);	
	g_free(filename);
	g_signal_connect(G_OBJECT(main_window),"delete-event",
						G_CALLBACK(del_event_handler),NULL);
	g_signal_connect(G_OBJECT(main_window),"destroy",
						G_CALLBACK(quit_from_main),NULL);
	
	return;
}
